"""Test compilation of integration tests for Nomic partner integration."""

import pytest


@pytest.mark.compile
def test_placeholder() -> None:
    """Used for compiling integration tests without running any real tests."""
